An ascending sequence of univarite knot locations.
Arguments
rangeval
A numeric vector of length 2 defining the
interval over which the functional data object can be
evaulated. The default value is 0:1.
nbasis
An integer specifying the number of
basis functions to construct. This is closely linked to
the number of knots (nknots), and
nknots = nbasis - norder.
nknots
The number of *interior* knots. See Details.
norder
An integer specifying the order of the B-splines, which is one higher than their degree. The default is 4, which corresponds to cubic splines.
extend
Should the knots stop at the endpoints specified by rangeval? Default is FALSE. See Details.
interior
A logical value specifying whether only interior knots should be returned. Default is FALSE.